@@ -40,22 +40,23 @@ void gui_info_refresh();
 void gui_timer_refresh(unsigned int);
 
 /* Tempo window functions */
+void gui_tempo_refresh();
 void gui_tempo_show();
 void gui_tempo_hide();
 void gui_tempo_changed(GtkAdjustment *, gpointer);
 void gui_tpl_changed(GtkAdjustment *, gpointer);
 
 /* Section list window functions */
-void gui_section_show();
-void gui_section_hide();
-void gui_section_refresh();
-void gui_section_select_row(GtkWidget *, gint, gint, GdkEventButton *, gpointer);
-void gui_section_insnew();
-void gui_section_appnew();
-void gui_section_delete();
-void gui_section_previous();
-void gui_section_next();
-void gui_section_activate_name(GtkWidget *, GtkWidget *);
+void gui_sectionlist_show();
+void gui_sectionlist_hide();
+void gui_sectionlist_refresh();
+void gui_sectionlist_select_row(GtkWidget *, gint, gint, GdkEventButton *, gpointer);
+void gui_sectionlist_insnew();
+void gui_sectionlist_appnew();
+void gui_sectionlist_delete();
+void gui_sectionlist_previous();
+void gui_sectionlist_next();
+void gui_sectionlist_activate_name(GtkWidget *, GtkWidget *);
 
 /* Playing sequence window functions */
 void gui_playseq_show();
