@@ -52,8 +52,8 @@ GtkWidget *gui_info_block1, *gui_info_block2;
 GtkWidget *gui_info_status, *gui_info_timer;
 
 /* Section List window GTK widgets */
-GtkWidget *gui_section_window, *gui_section_current, *gui_section_playseq;
-GtkWidget *gui_section_clist;
+GtkWidget *gui_sectionlist_window, *gui_sectionlist_current, *gui_sectionlist_playseq;
+GtkWidget *gui_sectionlist_clist;
 
 /* Playing Sequence window GTK widgets */
 GtkWidget *gui_playseq_window, *gui_playseq_current, *gui_playseq_block;
@@ -82,7 +82,7 @@ void gui_play_song() {
   gui_info_refresh();
   gui_blocklist_refresh();
   gui_playseq_refresh();
-  gui_section_refresh();
+  gui_sectionlist_refresh();
   gui_timer_refresh(0);
 }
 
@@ -136,6 +136,10 @@ void gui_file_saveas_clicked(GtkFileSelection *selector, gpointer user_data) {
 
 void gui_create() {
   GtkWidget *w1, *w2, *w3, *w4, *mainvbox, *tophbox, *instrvbox;
+  char *sectionlist_titles[3]={ "Position", "Playing Sequence Number",
+			    "Playing Sequence Name" };
+  char *playseq_titles[3]={ "Position", "Block Number", "Block Name" };
+  char *blocklist_titles[2]={ "Number", "Name" };
 
   /* Main window */
   gui_main_window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
@@ -200,7 +204,11 @@ void gui_create() {
   gtk_menu_bar_append(GTK_MENU_BAR(w1), w2);
   w3=gtk_menu_new();
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(w2), w3);
-  w4=gtk_menu_item_new_with_label("Tempo... AltGr+B");
+  w4=gtk_menu_item_new_with_label("Tempo... AltGr+T");
+  gtk_menu_append(GTK_MENU(w3), w4);
+  gtk_signal_connect(GTK_OBJECT(w4), "activate",
+		     GTK_SIGNAL_FUNC(gui_tempo_show), NULL);
+  w4=gtk_menu_item_new_with_label("Track Volumes... AltGr+V");
   gtk_menu_append(GTK_MENU(w3), w4);
   gtk_signal_connect(GTK_OBJECT(w4), "activate",
 		     GTK_SIGNAL_FUNC(gui_tempo_show), NULL);
@@ -305,46 +313,47 @@ void gui_create() {
 		     GTK_SIGNAL_FUNC(gui_main_changed), (gpointer)&editor.space);
   w2=gtk_spin_button_new(GTK_ADJUSTMENT(gui_main_space), 1, 0);
   gtk_box_pack_start(GTK_BOX(w1), w2, TRUE, TRUE, 4);
-  w2=gtk_label_new("Octave");
+  w2=gtk_label_new("Keyboard Octaves");
   gtk_box_pack_start(GTK_BOX(w1), w2, TRUE, TRUE, 4);
   gui_main_octave=gtk_option_menu_new();
   w3=gtk_menu_new();
-  w4=gtk_menu_item_new_with_label("12");
+  w4=gtk_menu_item_new_with_label("1 and 2");
   gtk_signal_connect(GTK_OBJECT(w4), "activate",
 		     GTK_SIGNAL_FUNC(gui_main_octave_activate), (gpointer)1);
   gtk_menu_append(GTK_MENU(w3), w4);
-  w4=gtk_menu_item_new_with_label("23");
+  w4=gtk_menu_item_new_with_label("2 and 3");
   gtk_signal_connect(GTK_OBJECT(w4), "activate",
 		     GTK_SIGNAL_FUNC(gui_main_octave_activate), (gpointer)2);
   gtk_menu_append(GTK_MENU(w3), w4);
-  w4=gtk_menu_item_new_with_label("34");
+  w4=gtk_menu_item_new_with_label("3 and 4");
   gtk_signal_connect(GTK_OBJECT(w4), "activate",
 		     GTK_SIGNAL_FUNC(gui_main_octave_activate), (gpointer)3);
   gtk_menu_append(GTK_MENU(w3), w4);
-  w4=gtk_menu_item_new_with_label("45");
+  w4=gtk_menu_item_new_with_label("4 and 5");
   gtk_signal_connect(GTK_OBJECT(w4), "activate",
 		     GTK_SIGNAL_FUNC(gui_main_octave_activate), (gpointer)4);
   gtk_menu_append(GTK_MENU(w3), w4);
-  w4=gtk_menu_item_new_with_label("56");
+  w4=gtk_menu_item_new_with_label("5 and 6");
   gtk_signal_connect(GTK_OBJECT(w4), "activate",
 		     GTK_SIGNAL_FUNC(gui_main_octave_activate), (gpointer)5);
   gtk_menu_append(GTK_MENU(w3), w4);
-  w4=gtk_menu_item_new_with_label("67");
+  w4=gtk_menu_item_new_with_label("6 and 7");
   gtk_signal_connect(GTK_OBJECT(w4), "activate",
 		     GTK_SIGNAL_FUNC(gui_main_octave_activate), (gpointer)6);
   gtk_menu_append(GTK_MENU(w3), w4);
-  w4=gtk_menu_item_new_with_label("78");
+  w4=gtk_menu_item_new_with_label("7 and 8");
   gtk_signal_connect(GTK_OBJECT(w4), "activate",
 		     GTK_SIGNAL_FUNC(gui_main_octave_activate), (gpointer)7);
   gtk_menu_append(GTK_MENU(w3), w4);
-  w4=gtk_menu_item_new_with_label("89");
+  w4=gtk_menu_item_new_with_label("8 and 9");
   gtk_signal_connect(GTK_OBJECT(w4), "activate",
 		     GTK_SIGNAL_FUNC(gui_main_octave_activate), (gpointer)8);
   gtk_menu_append(GTK_MENU(w3), w4);
-  w4=gtk_menu_item_new_with_label("9A");
+  w4=gtk_menu_item_new_with_label("9 and A");
   gtk_signal_connect(GTK_OBJECT(w4), "activate",
 		     GTK_SIGNAL_FUNC(gui_main_octave_activate), (gpointer)9);
   gtk_menu_append(GTK_MENU(w3), w4);
+  /* FIX: why is the menu too small? */
   gtk_option_menu_set_menu(GTK_OPTION_MENU(gui_main_octave), w3);
   gtk_box_pack_start(GTK_BOX(w1), gui_main_octave, TRUE, TRUE, 4);
 
@@ -355,12 +364,12 @@ void gui_create() {
   /* Info */
   w1=gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(mainvbox), w1, FALSE, FALSE, 0);
-  w2=gtk_button_new_with_label("Section");
+  w2=gtk_button_new_with_label("Section List");
   gtk_signal_connect(GTK_OBJECT(w2), "clicked",
-		     GTK_SIGNAL_FUNC(gui_section_show), NULL);
+		     GTK_SIGNAL_FUNC(gui_sectionlist_show), NULL);
   gtk_box_pack_start(GTK_BOX(w1), w2, TRUE, TRUE, 4);
   w2=gtk_frame_new(NULL);
-  gui_info_section=gtk_label_new("");
+  gui_info_section=gtk_label_new("Section 1/1");
   gtk_frame_set_shadow_type(GTK_FRAME(w2), GTK_SHADOW_IN);
   gtk_container_add(GTK_CONTAINER(w2), gui_info_section);
   gtk_box_pack_start(GTK_BOX(w1), w2, TRUE, TRUE, 0);
@@ -369,11 +378,11 @@ void gui_create() {
 		     GTK_SIGNAL_FUNC(gui_playseq_show), NULL);
   gtk_box_pack_start(GTK_BOX(w1), w2, TRUE, TRUE, 4);
   w2=gtk_frame_new(NULL);
-  gui_info_playseq=gtk_label_new("");
+  gui_info_playseq=gtk_label_new("Position 1/1");
   gtk_frame_set_shadow_type(GTK_FRAME(w2), GTK_SHADOW_IN);
   gtk_container_add(GTK_CONTAINER(w2), gui_info_playseq);
   gtk_box_pack_start(GTK_BOX(w1), w2, TRUE, TRUE, 0);
-  w2=gtk_button_new_with_label("Block");
+  w2=gtk_button_new_with_label("Block List");
   gtk_signal_connect(GTK_OBJECT(w2), "clicked",
 		     GTK_SIGNAL_FUNC(gui_blocklist_show), NULL);
   gtk_box_pack_start(GTK_BOX(w1), w2, TRUE, TRUE, 4);
@@ -382,7 +391,7 @@ void gui_create() {
   gtk_box_pack_start(GTK_BOX(w1), w2, TRUE, TRUE, 4);
   w3=gtk_hbox_new(FALSE, 4);
   gtk_container_add(GTK_CONTAINER(w2), w3);
-  gui_info_block1=gtk_label_new("");
+  gui_info_block1=gtk_label_new("Block 0/0");
   gui_info_block2=gtk_label_new("");
   gtk_box_pack_start(GTK_BOX(w3), gui_info_block1, TRUE, TRUE, 0);
   gtk_box_pack_start(GTK_BOX(w3), gui_info_block2, TRUE, TRUE, 0);
@@ -392,7 +401,7 @@ void gui_create() {
   w3=gtk_frame_new(NULL);
   gtk_frame_set_shadow_type(GTK_FRAME(w3), GTK_SHADOW_IN);
   gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 4);
-  gui_info_status=gtk_label_new("- Stopped -");
+  gui_info_status=gtk_label_new("Stopped");
   gtk_container_add(GTK_CONTAINER(w3), gui_info_status);
   w3=gtk_frame_new(NULL);
   gtk_frame_set_shadow_type(GTK_FRAME(w3), GTK_SHADOW_OUT);
@@ -422,7 +431,7 @@ void gui_create() {
   gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 4);
   w4=gtk_label_new("Tempo");
   gtk_box_pack_start(GTK_BOX(w3), w4, FALSE, FALSE, 4);
-  gui_tempo_adjustment_tempo=(GtkWidget *)gtk_adjustment_new(125, 1,
+  gui_tempo_adjustment_tempo=(GtkWidget *)gtk_adjustment_new(DEFAULT_TEMPO, 1,
 							 240, 1, 1, 0);
   gtk_signal_connect(GTK_OBJECT(gui_tempo_adjustment_tempo), "value_changed",
 		     GTK_SIGNAL_FUNC(gui_tempo_changed), NULL);
@@ -446,64 +455,74 @@ void gui_create() {
   gtk_box_pack_start(GTK_BOX(w1), w3, FALSE, FALSE, 0);
 
   /* Section list window */
-  gui_section_window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
-  gtk_container_set_border_width(GTK_CONTAINER(gui_section_window), 4);
-  gtk_window_set_title(GTK_WINDOW(gui_section_window), "Section List");
-  gtk_widget_add_events(GTK_WIDGET(gui_section_window), GDK_KEY_RELEASE_MASK);
-  gtk_signal_connect(GTK_OBJECT(gui_section_window), "key_press_event",
+  gui_sectionlist_window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
+  gtk_container_set_border_width(GTK_CONTAINER(gui_sectionlist_window), 4);
+  gtk_window_set_title(GTK_WINDOW(gui_sectionlist_window), "Section List");
+  gtk_widget_add_events(GTK_WIDGET(gui_sectionlist_window), GDK_KEY_RELEASE_MASK);
+  gtk_signal_connect(GTK_OBJECT(gui_sectionlist_window), "key_press_event",
 		     GTK_SIGNAL_FUNC(keyboard_event), (gpointer)1);
-  gtk_signal_connect(GTK_OBJECT(gui_section_window), "key_release_event",
+  gtk_signal_connect(GTK_OBJECT(gui_sectionlist_window), "key_release_event",
 		     GTK_SIGNAL_FUNC(keyboard_event), (gpointer)0);
 
   w1=gtk_vbox_new(FALSE, 0);
-  gtk_container_add(GTK_CONTAINER(gui_section_window), w1);
+  gtk_container_add(GTK_CONTAINER(gui_sectionlist_window), w1);
   w2=gtk_scrolled_window_new(NULL, NULL);
   gtk_box_pack_start(GTK_BOX(w1), w2, TRUE, TRUE, 0);
   gtk_container_set_border_width(GTK_CONTAINER(w2), 0);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(w2), GTK_POLICY_NEVER,
 				 GTK_POLICY_AUTOMATIC);
-  gui_section_clist=gtk_clist_new(3);
-  gtk_clist_set_column_width(GTK_CLIST(gui_section_clist), 0, 30);
-  gtk_clist_set_column_width(GTK_CLIST(gui_section_clist), 1, 30);
-  gtk_clist_set_column_width(GTK_CLIST(gui_section_clist), 2, 140);
-  gtk_clist_set_selection_mode(GTK_CLIST(gui_section_clist), GTK_SELECTION_BROWSE);
-  gtk_signal_connect(GTK_OBJECT(gui_section_clist), "select_row",
-		     GTK_SIGNAL_FUNC(gui_section_select_row), NULL);
-  gtk_container_add(GTK_CONTAINER(w2), gui_section_clist);
-  w2=gtk_hbox_new(FALSE,0);
-  gtk_box_pack_start(GTK_BOX(w1), w2, FALSE, FALSE, 4);
-  gui_section_current=gtk_label_new("");
-  gtk_box_pack_start(GTK_BOX(w2), gui_section_current, TRUE, TRUE, 0);
-  gui_section_playseq=gtk_label_new("");
-  gtk_box_pack_start(GTK_BOX(w2), gui_section_playseq, TRUE, TRUE, 0);
-  w3=gtk_button_new_with_label("<");
-  gtk_signal_connect(GTK_OBJECT(w3), "clicked",
-		     GTK_SIGNAL_FUNC(gui_section_previous), NULL);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 4);
-  w3=gtk_button_new_with_label(">");
-  gtk_signal_connect(GTK_OBJECT(w3), "clicked",
-		     GTK_SIGNAL_FUNC(gui_section_next), NULL);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 0);
+  gui_sectionlist_clist=gtk_clist_new_with_titles(3, sectionlist_titles);
+  gtk_clist_set_column_width(GTK_CLIST(gui_sectionlist_clist), 0, 30);
+  gtk_clist_set_column_width(GTK_CLIST(gui_sectionlist_clist), 1, 30);
+  gtk_clist_set_column_width(GTK_CLIST(gui_sectionlist_clist), 2, 140);
+  gtk_clist_set_column_auto_resize(GTK_CLIST(gui_sectionlist_clist), 0, TRUE);
+  gtk_clist_set_column_auto_resize(GTK_CLIST(gui_sectionlist_clist), 1, TRUE);
+  gtk_clist_set_column_auto_resize(GTK_CLIST(gui_sectionlist_clist), 2, TRUE);
+  gtk_clist_set_selection_mode(GTK_CLIST(gui_sectionlist_clist),
+			       GTK_SELECTION_BROWSE);
+  gtk_signal_connect(GTK_OBJECT(gui_sectionlist_clist), "select_row",
+		     GTK_SIGNAL_FUNC(gui_sectionlist_select_row), NULL);
+  gtk_container_add(GTK_CONTAINER(w2), gui_sectionlist_clist);
 
-  w2=gtk_hbox_new(FALSE,0);
-  gtk_box_pack_start(GTK_BOX(w1), w2, FALSE, FALSE, 0);
-  w3=gtk_button_new_with_label("Insert");
-  gtk_signal_connect(GTK_OBJECT(w3), "clicked",
-		     GTK_SIGNAL_FUNC(gui_section_insnew), NULL);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 0);
-  w3=gtk_button_new_with_label("Append");
-  gtk_signal_connect(GTK_OBJECT(w3), "clicked",
-		     GTK_SIGNAL_FUNC(gui_section_appnew), NULL);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 4);
-  w3=gtk_button_new_with_label("Delete");
-  gtk_signal_connect(GTK_OBJECT(w3), "clicked",
-		     GTK_SIGNAL_FUNC(gui_section_delete), NULL);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 0);
+  gui_sectionlist_current=gtk_frame_new("Section 1/1");
+  gtk_frame_set_shadow_type(GTK_FRAME(gui_sectionlist_current),
+			    GTK_SHADOW_ETCHED_IN);
+  gtk_box_pack_start(GTK_BOX(w1), gui_sectionlist_current, FALSE, FALSE, 4);
+  w2=gtk_vbox_new(FALSE, 0);
+  gtk_container_add(GTK_CONTAINER(gui_sectionlist_current), w2);
+
+  w3=gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(w2), w3, FALSE, FALSE, 0);
+  gui_sectionlist_playseq=gtk_label_new("Playing Sequence 1/1");
+  gtk_box_pack_start(GTK_BOX(w3), gui_sectionlist_playseq, FALSE, FALSE, 4);
+  w4=gtk_button_new_with_label("<");
+  gtk_signal_connect(GTK_OBJECT(w4), "clicked",
+		     GTK_SIGNAL_FUNC(gui_sectionlist_previous), NULL);
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 0);
+  w4=gtk_button_new_with_label(">");
+  gtk_signal_connect(GTK_OBJECT(w4), "clicked",
+		     GTK_SIGNAL_FUNC(gui_sectionlist_next), NULL);
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
+
+  w3=gtk_hbox_new(FALSE,0);
+  gtk_box_pack_start(GTK_BOX(w2), w3, FALSE, FALSE, 4);
+  w4=gtk_button_new_with_label("Insert");
+  gtk_signal_connect(GTK_OBJECT(w4), "clicked",
+		     GTK_SIGNAL_FUNC(gui_sectionlist_insnew), NULL);
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
+  w4=gtk_button_new_with_label("Append");
+  gtk_signal_connect(GTK_OBJECT(w4), "clicked",
+		     GTK_SIGNAL_FUNC(gui_sectionlist_appnew), NULL);
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 0);
+  w4=gtk_button_new_with_label("Delete");
+  gtk_signal_connect(GTK_OBJECT(w4), "clicked",
+		     GTK_SIGNAL_FUNC(gui_sectionlist_delete), NULL);
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
 
   w2=gtk_button_new_with_label("Close");
   gtk_signal_connect(GTK_OBJECT(w2), "clicked",
-		     GTK_SIGNAL_FUNC(gui_section_hide), NULL);
-  gtk_box_pack_start(GTK_BOX(w1), w2, FALSE, FALSE, 4);
+		     GTK_SIGNAL_FUNC(gui_sectionlist_hide), NULL);
+  gtk_box_pack_start(GTK_BOX(w1), w2, FALSE, FALSE, 0);
 
   /* Playing sequence window */
   gui_playseq_window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
@@ -522,48 +541,57 @@ void gui_create() {
   gtk_container_set_border_width(GTK_CONTAINER(w2), 0);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(w2), GTK_POLICY_NEVER,
 				 GTK_POLICY_AUTOMATIC);
-  gui_playseq_clist=gtk_clist_new(3);
+  gui_playseq_clist=gtk_clist_new_with_titles(3, playseq_titles);
   gtk_clist_set_column_width(GTK_CLIST(gui_playseq_clist), 0, 30);
   gtk_clist_set_column_width(GTK_CLIST(gui_playseq_clist), 1, 30);
   gtk_clist_set_column_width(GTK_CLIST(gui_playseq_clist), 2, 140);
+  gtk_clist_set_column_auto_resize(GTK_CLIST(gui_playseq_clist), 0, TRUE);
+  gtk_clist_set_column_auto_resize(GTK_CLIST(gui_playseq_clist), 1, TRUE);
+  gtk_clist_set_column_auto_resize(GTK_CLIST(gui_playseq_clist), 2, TRUE);
   gtk_clist_set_selection_mode(GTK_CLIST(gui_playseq_clist), GTK_SELECTION_BROWSE);
   gtk_signal_connect(GTK_OBJECT(gui_playseq_clist), "select_row",
 		     GTK_SIGNAL_FUNC(gui_playseq_select_row), NULL);
   gtk_container_add(GTK_CONTAINER(w2), gui_playseq_clist);
-  w2=gtk_hbox_new(FALSE,0);
-  gtk_box_pack_start(GTK_BOX(w1), w2, FALSE, FALSE, 4);
-  gui_playseq_current=gtk_label_new("");
-  gtk_box_pack_start(GTK_BOX(w2), gui_playseq_current, TRUE, TRUE, 0);
-  gui_playseq_block=gtk_label_new("");
-  gtk_box_pack_start(GTK_BOX(w2), gui_playseq_block, TRUE, TRUE, 0);
-  w3=gtk_button_new_with_label("<");
-  gtk_signal_connect(GTK_OBJECT(w3), "clicked",
-		     GTK_SIGNAL_FUNC(gui_playseq_previous), NULL);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 4);
-  w3=gtk_button_new_with_label(">");
-  gtk_signal_connect(GTK_OBJECT(w3), "clicked",
-		     GTK_SIGNAL_FUNC(gui_playseq_next), NULL);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 0);
 
-  w2=gtk_hbox_new(FALSE,0);
-  gtk_box_pack_start(GTK_BOX(w1), w2, FALSE, FALSE, 0);
-  w3=gtk_button_new_with_label("Insert");
-  gtk_signal_connect(GTK_OBJECT(w3), "clicked",
+  gui_playseq_current=gtk_frame_new("Position 1/1");
+  gtk_frame_set_shadow_type(GTK_FRAME(gui_playseq_current),
+			    GTK_SHADOW_ETCHED_IN);
+  gtk_box_pack_start(GTK_BOX(w1), gui_playseq_current, FALSE, FALSE, 4);
+  w2=gtk_vbox_new(FALSE, 0);
+  gtk_container_add(GTK_CONTAINER(gui_playseq_current), w2);
+
+  w3=gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(w2), w3, FALSE, FALSE, 0);
+  gui_playseq_block=gtk_label_new("Block 0/0");
+  gtk_box_pack_start(GTK_BOX(w3), gui_playseq_block, FALSE, FALSE, 4);
+  w4=gtk_button_new_with_label("<");
+  gtk_signal_connect(GTK_OBJECT(w4), "clicked",
+		     GTK_SIGNAL_FUNC(gui_playseq_previous), NULL);
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 0);
+  w4=gtk_button_new_with_label(">");
+  gtk_signal_connect(GTK_OBJECT(w4), "clicked",
+		     GTK_SIGNAL_FUNC(gui_playseq_next), NULL);
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
+
+  w3=gtk_hbox_new(FALSE,0);
+  gtk_box_pack_start(GTK_BOX(w2), w3, FALSE, FALSE, 4);
+  w4=gtk_button_new_with_label("Insert");
+  gtk_signal_connect(GTK_OBJECT(w4), "clicked",
 		     GTK_SIGNAL_FUNC(gui_playseq_insnew), NULL);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 0);
-  w3=gtk_button_new_with_label("Append");
-  gtk_signal_connect(GTK_OBJECT(w3), "clicked",
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
+  w4=gtk_button_new_with_label("Append");
+  gtk_signal_connect(GTK_OBJECT(w4), "clicked",
 		     GTK_SIGNAL_FUNC(gui_playseq_appnew), NULL);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 4);
-  w3=gtk_button_new_with_label("Delete");
-  gtk_signal_connect(GTK_OBJECT(w3), "clicked",
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 0);
+  w4=gtk_button_new_with_label("Delete");
+  gtk_signal_connect(GTK_OBJECT(w4), "clicked",
 		     GTK_SIGNAL_FUNC(gui_playseq_delete), NULL);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
 
   w2=gtk_button_new_with_label("Close");
   gtk_signal_connect(GTK_OBJECT(w2), "clicked",
 		     GTK_SIGNAL_FUNC(gui_playseq_hide), NULL);
-  gtk_box_pack_start(GTK_BOX(w1), w2, FALSE, FALSE, 4);
+  gtk_box_pack_start(GTK_BOX(w1), w2, FALSE, FALSE, 0);
 
   /* Block list window */
   gui_blocklist_window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
@@ -582,69 +610,72 @@ void gui_create() {
   gtk_container_set_border_width(GTK_CONTAINER(w2), 0);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(w2), GTK_POLICY_NEVER,
 				 GTK_POLICY_AUTOMATIC);
-  gui_blocklist_clist=gtk_clist_new(2);
+  gui_blocklist_clist=gtk_clist_new_with_titles(2, blocklist_titles);
   gtk_clist_set_column_width(GTK_CLIST(gui_blocklist_clist), 0, 30);
   gtk_clist_set_column_width(GTK_CLIST(gui_blocklist_clist), 1, 170);
+  gtk_clist_set_column_auto_resize(GTK_CLIST(gui_blocklist_clist), 0, TRUE);
+  gtk_clist_set_column_auto_resize(GTK_CLIST(gui_blocklist_clist), 1, TRUE);
   gtk_clist_set_selection_mode(GTK_CLIST(gui_blocklist_clist), GTK_SELECTION_BROWSE);
   gtk_signal_connect(GTK_OBJECT(gui_blocklist_clist), "select_row",
 		     GTK_SIGNAL_FUNC(gui_blocklist_select_row), NULL);
   gtk_container_add(GTK_CONTAINER(w2), gui_blocklist_clist);
 
-  w2=gtk_hbox_new(FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(w1), w2, FALSE, FALSE, 4);
-  w3=gtk_label_new("Block");
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 0);
-  gui_blocklist_current=gtk_label_new("");
-  gtk_box_pack_start(GTK_BOX(w2), gui_blocklist_current, TRUE, TRUE, 0);
-  w3=gtk_label_new("Name:");
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 0);
+  gui_blocklist_current=gtk_frame_new("Block 0/0");
+  gtk_frame_set_shadow_type(GTK_FRAME(gui_blocklist_current),
+			    GTK_SHADOW_ETCHED_IN);
+  gtk_box_pack_start(GTK_BOX(w1), gui_blocklist_current, FALSE, FALSE, 4);
+  w2=gtk_vbox_new(FALSE, 0);
+  gtk_container_add(GTK_CONTAINER(gui_blocklist_current), w2);
+  w3=gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(w2), w3, FALSE, FALSE, 4);
+  w4=gtk_label_new("Name");
+  gtk_box_pack_start(GTK_BOX(w3), w4, FALSE, FALSE, 4);
+  gtk_label_set_justify(GTK_LABEL(w4), GTK_JUSTIFY_RIGHT);
   gui_blocklist_entry_name=gtk_entry_new();
   gtk_signal_connect(GTK_OBJECT(gui_blocklist_entry_name), "activate",
 		     GTK_SIGNAL_FUNC(gui_blocklist_activate_name), gui_blocklist_entry_name);
-  gtk_box_pack_start(GTK_BOX(w2), gui_blocklist_entry_name, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(w3), gui_blocklist_entry_name, TRUE, TRUE, 4);
 
-  w2=gtk_hbox_new(FALSE, 4);
-  gtk_box_pack_start(GTK_BOX(w1), w2, FALSE, FALSE, 0);
-  w3=gtk_label_new("Tracks");
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 4);
-  gui_blocklist_tracks=(GtkWidget *)gtk_adjustment_new(4, 1, 255, 1, 1,
-							     0);
+  w3=gtk_hbox_new(FALSE, 4);
+  gtk_box_pack_start(GTK_BOX(w2), w3, FALSE, FALSE, 0);
+  w4=gtk_label_new("Tracks");
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
+  gui_blocklist_tracks=(GtkWidget *)gtk_adjustment_new(4, 1, 255, 1, 1, 0);
   gtk_signal_connect(GTK_OBJECT(gui_blocklist_tracks), "value_changed",
 		     GTK_SIGNAL_FUNC(gui_blocklist_tracks_changed), NULL);
-  w3=gtk_spin_button_new(GTK_ADJUSTMENT(gui_blocklist_tracks), 1, 0);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 4);
-  w3=gtk_label_new("Length");
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 4);
-  gui_blocklist_length=(GtkWidget *)gtk_adjustment_new(64, 1, 255, 1, 1,
-							     0);
+  w4=gtk_spin_button_new(GTK_ADJUSTMENT(gui_blocklist_tracks), 1, 0);
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
+  w4=gtk_label_new("Length");
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
+  gui_blocklist_length=(GtkWidget *)gtk_adjustment_new(64, 1, 255, 1, 1, 0);
   gtk_signal_connect(GTK_OBJECT(gui_blocklist_length), "value_changed",
 		     GTK_SIGNAL_FUNC(gui_blocklist_length_changed), NULL);
-  w3=gtk_spin_button_new(GTK_ADJUSTMENT(gui_blocklist_length), 1, 0);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 4);
-  w3=gtk_label_new("Command pages");
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 4);
+  w4=gtk_spin_button_new(GTK_ADJUSTMENT(gui_blocklist_length), 1, 0);
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
+  w4=gtk_label_new("Command pages");
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
   gui_blocklist_effectpages=(GtkWidget *)gtk_adjustment_new(1, 1, 255,
-								   1, 1, 0);
+							    1, 1, 0);
   gtk_signal_connect(GTK_OBJECT(gui_blocklist_effectpages), "value_changed",
 		     GTK_SIGNAL_FUNC(gui_blocklist_effectpages_changed), NULL);
-  w3=gtk_spin_button_new(GTK_ADJUSTMENT(gui_blocklist_effectpages), 1,
-			 0);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 4);
+  w4=gtk_spin_button_new(GTK_ADJUSTMENT(gui_blocklist_effectpages), 1, 0);
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
 
-  w2=gtk_hbox_new(FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(w1), w2, FALSE, FALSE, 4);
-  w3=gtk_button_new_with_label("Insert New");
-  gtk_signal_connect(GTK_OBJECT(w3), "clicked",
+  w3=gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(w2), w3, FALSE, FALSE, 4);
+  w4=gtk_button_new_with_label("Insert New");
+  gtk_signal_connect(GTK_OBJECT(w4), "clicked",
 		     GTK_SIGNAL_FUNC(gui_blocklist_insnew), NULL);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 0);
-  w3=gtk_button_new_with_label("Append New");
-  gtk_signal_connect(GTK_OBJECT(w3), "clicked",
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
+  w4=gtk_button_new_with_label("Append New");
+  gtk_signal_connect(GTK_OBJECT(w4), "clicked",
 		     GTK_SIGNAL_FUNC(gui_blocklist_appnew), NULL);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 4);
-  w3=gtk_button_new_with_label("Delete");
-  gtk_signal_connect(GTK_OBJECT(w3), "clicked",
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 0);
+  w4=gtk_button_new_with_label("Delete");
+  gtk_signal_connect(GTK_OBJECT(w4), "clicked",
 		     GTK_SIGNAL_FUNC(gui_blocklist_delete), NULL);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
+
   w2=gtk_button_new_with_label("Close");
   gtk_signal_connect(GTK_OBJECT(w2), "clicked",
 		     GTK_SIGNAL_FUNC(gui_blocklist_hide), NULL);
@@ -739,8 +770,6 @@ void gui_main_refresh() {
   tracker_reset((Tracker *)gui_main_tracker);
   tracker_set_pattern((Tracker *)gui_main_tracker, editor.song->blocks[0]);
   tracker_set_num_channels((Tracker *)gui_main_tracker, editor.song->blocks[0]->tracks);
-
-  gtk_label_set_text(GTK_LABEL(gui_info_status), "- Stopped -");
 }
 
 void gui_main_show() {
@@ -748,6 +777,13 @@ void gui_main_show() {
   gtk_widget_show_all(gui_main_window);
 }
 
+void gui_tempo_refresh() {
+  gtk_adjustment_set_value(GTK_ADJUSTMENT(gui_tempo_adjustment_tempo),
+			   editor.song->tempo);
+  gtk_adjustment_set_value(GTK_ADJUSTMENT(gui_tempo_adjustment_tpl),
+			   editor.song->ticksperline);
+}
+
 void gui_tempo_show() {
   gtk_window_set_default_size(GTK_WINDOW(gui_tempo_window), 200, 100);
   gtk_widget_show_all(gui_tempo_window);
@@ -758,13 +794,13 @@ void gui_tempo_hide() {
 }
 
 void gui_info_refresh() {
-  char section[8], playseq[8], block[9], title[76];
+  char section[9+8], playseq[10+8], block[7+9], title[76];
 
-  snprintf(section, 8, "%d/%d", editor.section+1,
+  snprintf(section, 8+8, "Section %d/%d", editor.section+1,
 	   editor.song->numsections);
-  snprintf(playseq, 8, "%d/%d", editor.playseqpos+1,
+  snprintf(playseq, 9+8, "Position %d/%d", editor.playseqpos+1,
 	   editor.song->playseqs[editor.playseq]->length);
-  snprintf(block, 9, "%d/%d:", editor.block, editor.song->numblocks-1);
+  snprintf(block, 6+9, "Block %d/%d:", editor.block, editor.song->numblocks-1);
   gtk_label_set_text(GTK_LABEL(gui_info_section), section);
   gtk_label_set_text(GTK_LABEL(gui_info_playseq), playseq);
   gtk_label_set_text(GTK_LABEL(gui_info_block1), block);
@@ -787,7 +823,7 @@ void gui_info_refresh() {
     gtk_label_set_text(GTK_LABEL(gui_info_status), "Playing block");
     break;
   case MODE_IDLE:
-    gtk_label_set_text(GTK_LABEL(gui_info_status), "- Stopped -");
+    gtk_label_set_text(GTK_LABEL(gui_info_status), "Stopped");
     break;
   }
 }
@@ -839,57 +875,59 @@ void gui_instrument_hold_changed(GtkAdjustment *adjustment,
   editor.song->instruments[editor.instrument]->transpose=(unsigned char)adjustment->value;
 }
 
-void gui_section_show() {
-  gtk_window_set_default_size(GTK_WINDOW(gui_section_window), 200, 300);
-  gtk_widget_show_all(gui_section_window);
+void gui_sectionlist_show() {
+  gtk_window_set_default_size(GTK_WINDOW(gui_sectionlist_window), 200, 300);
+  gtk_widget_show_all(gui_sectionlist_window);
 }
 
-void gui_section_hide() {
-  gtk_widget_hide(gui_section_window);
+void gui_sectionlist_hide() {
+  gtk_widget_hide(gui_sectionlist_window);
 }
 
-void gui_section_refresh() {
+void gui_sectionlist_refresh() {
   int i;
   unsigned short section=editor.section;
   char position[4];
   char playseq[4];
   char *columns[3];
 
-  gtk_clist_freeze(GTK_CLIST(gui_section_clist));
-  gtk_clist_clear(GTK_CLIST(gui_section_clist));
+  gtk_clist_freeze(GTK_CLIST(gui_sectionlist_clist));
+  gtk_clist_clear(GTK_CLIST(gui_sectionlist_clist));
   columns[0]=position;
   columns[1]=playseq;
   for(i=0; i<editor.song->numsections; i++) {
     snprintf(position, 4, "%0.3d", i+1);
-    snprintf(playseq, 4, "%0.3d", editor.song->sections[i]);
+    snprintf(playseq, 4, "%0.3d", editor.song->sections[i]+1);
     columns[2]=editor.song->playseqs[editor.song->sections[i]]->name;
-    gtk_clist_append(GTK_CLIST(gui_section_clist), columns);
+    gtk_clist_append(GTK_CLIST(gui_sectionlist_clist), columns);
   }
 
-  gtk_clist_thaw(GTK_CLIST(gui_section_clist));
-  gtk_clist_select_row(GTK_CLIST(gui_section_clist), section, 0);
-  gtk_clist_moveto(GTK_CLIST(gui_section_clist), section, 0, 0, 0);
+  gtk_clist_thaw(GTK_CLIST(gui_sectionlist_clist));
+  gtk_clist_select_row(GTK_CLIST(gui_sectionlist_clist), section, 0);
+  gtk_clist_moveto(GTK_CLIST(gui_sectionlist_clist), section, 0, 0, 0);
 }
 
-void gui_section_select_row(GtkWidget *list, gint row, gint column,
+void gui_sectionlist_select_row(GtkWidget *list, gint row, gint column,
 		      GdkEventButton *event, gpointer data) {
-  char section[8];
-  char playseq[8];
+  char section[8+8];
+  char playseq[17+8];
 
   editor.section=row;
   editor.playseq=editor.song->sections[editor.section];
 
-  snprintf(section, 8, "%3d/%-3d", editor.section+1, editor.song->numsections);
-  snprintf(playseq, 8, "%3d/%-3d", editor.playseq+1, editor.song->numplayseqs);
+  snprintf(section, 8+8, "Section %d/%d", editor.section+1,
+	   editor.song->numsections);
+  snprintf(playseq, 17+8, "Playing Sequence %d/%d", editor.playseq+1,
+	   editor.song->numplayseqs);
 
-  gtk_label_set_text(GTK_LABEL(gui_section_current), section);
-  gtk_label_set_text(GTK_LABEL(gui_section_playseq), playseq);
+  gtk_frame_set_label(GTK_FRAME(gui_sectionlist_current), section);
+  gtk_label_set_text(GTK_LABEL(gui_sectionlist_playseq), playseq);
 
   gui_info_refresh();
 }
 
 #ifdef hmm
-void section_activate_name(GtkWidget *widget, GtkWidget *entry) {
+void sectionlist_activate_name(GtkWidget *widget, GtkWidget *entry) {
   char *name=gtk_entry_get_text(GTK_ENTRY(entry));
 
   if(editor.song->sections[editor.section]->name)
@@ -897,49 +935,49 @@ void section_activate_name(GtkWidget *widget, GtkWidget *entry) {
 
   editor.song->sections[editor.section]->name=(char *)strdup(name);
 
-  gui_section_refresh();
+  gui_sectionlist_refresh();
 }
 #endif
 
-void gui_section_insnew() {
+void gui_sectionlist_insnew() {
   if(editor.song!=NULL) {
     song_insertsection(editor.song, editor.section);
-    gui_section_refresh();
+    gui_sectionlist_refresh();
   }
 }
 
-void gui_section_appnew() {
+void gui_sectionlist_appnew() {
   if(editor.song!=NULL) {
     song_insertsection(editor.song, editor.song->numsections);
-    gui_section_refresh();
+    gui_sectionlist_refresh();
   }
 }
 
-void gui_section_delete() {
+void gui_sectionlist_delete() {
   if(editor.song!=NULL) {
     song_deletesection(editor.song, editor.section);
     if(editor.section>=editor.song->numsections)
       editor.section=editor.song->numsections-1;
-    gui_section_refresh();
+    gui_sectionlist_refresh();
   }
 }
 
-void gui_section_previous() {
+void gui_sectionlist_previous() {
   if(editor.song->sections[editor.playseq]>0)
     editor.song->sections[editor.playseq]--;
 
-  gui_section_refresh();
+  gui_sectionlist_refresh();
 }
 
-void gui_section_next() {
+void gui_sectionlist_next() {
   if(editor.song->sections[editor.playseq]<editor.song->numplayseqs-1)
     editor.song->sections[editor.playseq]++;
 
-  gui_section_refresh();
+  gui_sectionlist_refresh();
 }
 
 void gui_playseq_show() {
-  gtk_window_set_default_size(GTK_WINDOW(gui_playseq_window), 200, 300);
+  gtk_window_set_default_size(GTK_WINDOW(gui_playseq_window), 250, 300);
   gtk_widget_show_all(gui_playseq_window);
 }
 
@@ -950,9 +988,10 @@ void gui_playseq_hide() {
 void gui_playseq_refresh() {
   int i;
   unsigned short playseqpos=editor.playseqpos;
-  char position[4];
-  char block[4];
+  char position[9+8];
+  char block[6+8];
   char *columns[3];
+  char title[21];
 
   gtk_clist_freeze(GTK_CLIST(gui_playseq_clist));
   gtk_clist_clear(GTK_CLIST(gui_playseq_clist));
@@ -969,20 +1008,28 @@ void gui_playseq_refresh() {
   gtk_clist_thaw(GTK_CLIST(gui_playseq_clist));
   gtk_clist_select_row(GTK_CLIST(gui_playseq_clist), playseqpos, 0);
   gtk_clist_moveto(GTK_CLIST(gui_playseq_clist), playseqpos, 0, 0, 0);
+
+  snprintf(position, 9+8, "Position %d/%d", editor.playseqpos+1,
+	   editor.song->playseqs[editor.playseq]->length);
+  snprintf(block, 6+8, "Block %d/%d", editor.song->playseqs[editor.section]->blocknumbers[editor.playseqpos], editor.song->numblocks-1);
+  gtk_frame_set_label(GTK_FRAME(gui_playseq_current), position);
+  gtk_label_set_text(GTK_LABEL(gui_playseq_block), block);
+
+  snprintf(title, 21, "Playing Sequence %d", editor.section);
+  gtk_window_set_title(GTK_WINDOW(gui_playseq_window), title);
 }
 
 void gui_playseq_select_row(GtkWidget *list, gint row, gint column,
 		      GdkEventButton *event, gpointer data) {
-  char playseqpos[8];
-  char block[8];
+  char position[9+8];
+  char block[6+8];
 
   editor.playseqpos=row;
 
-  snprintf(playseqpos, 8, "%3d/%-3d", editor.playseqpos+1,
+  snprintf(position, 9+8, "Position %d/%d", editor.playseqpos+1,
 	   editor.song->playseqs[editor.playseq]->length);
-  snprintf(block, 8, "%3d/%-3d", editor.block, editor.song->numblocks-1);
-
-  gtk_label_set_text(GTK_LABEL(gui_playseq_current), playseqpos);
+  snprintf(block, 6+8, "Block %d/%d", editor.song->playseqs[editor.section]->blocknumbers[editor.playseqpos], editor.song->numblocks-1);
+  gtk_frame_set_label(GTK_FRAME(gui_playseq_current), position);
   gtk_label_set_text(GTK_LABEL(gui_playseq_block), block);
 
   gui_info_refresh();
@@ -1066,7 +1113,7 @@ void gui_blocklist_refresh() {
 
 void gui_blocklist_select_row(GtkWidget *list, gint row, gint column,
 		      GdkEventButton *event, gpointer data) {
-  char block[8];
+  char block[6+8];
 
   editor.block=row;
 
@@ -1076,10 +1123,10 @@ void gui_blocklist_select_row(GtkWidget *list, gint row, gint column,
   else
     gtk_entry_set_text(GTK_ENTRY(gui_blocklist_entry_name), "");
 
-  snprintf(block, 8, "%3d/%-3d", editor.block,
+  snprintf(block, 6+8, "Block %d/%d", editor.block,
 	   editor.song->numblocks-1);
 
-  gtk_label_set_text(GTK_LABEL(gui_blocklist_current), block);
+  gtk_frame_set_label(GTK_FRAME(gui_blocklist_current), block);
 
   gui_info_refresh();
   tracker_set_pattern((Tracker *)gui_main_tracker, editor.song->blocks[row]);
@@ -1112,6 +1159,7 @@ void gui_blocklist_insnew() {
   if(editor.song!=NULL) {
     song_insertblock(editor.song, editor.block);
     gui_blocklist_refresh();
+    gui_playseq_refresh();
   }
 }
 
@@ -1119,6 +1167,7 @@ void gui_blocklist_appnew() {
   if(editor.song!=NULL) {
     song_insertblock(editor.song, editor.song->numblocks);
     gui_blocklist_refresh();
+    gui_playseq_refresh();
   }
 }
 
@@ -1126,6 +1175,7 @@ void gui_blocklist_delete() {
   if(editor.song!=NULL) {
     song_deleteblock(editor.song, editor.block);
     gui_blocklist_refresh();
+    gui_playseq_refresh();
   }
 }
 
