@@ -347,7 +347,7 @@ struct song *song_convertMMD2(struct MMD2 *mmd) {
     song->maxtracks=mmd->song->numtracks;
     song->trackvolumes=(char *)calloc(song->maxtracks, sizeof(char));
   } else {
-    song->tempo=130;
+    song->tempo=DEFAULT_TEMPO;
     song->ticksperline=6;
     song->numsections=1;
     song->sections=(unsigned short *)calloc(1, sizeof(unsigned short));
